
const path = require('path');

let cfg = {};
let dest = '';
let dir = '';
let originalAddrList = new Array();
let mId = '';
let prefixNum = 0;
let downloadAddrList = new Array();
let saveAddrList = new Array();
let replaceAddrList = new Array();

function reset() {
    cfg = {};
    dest = '';
    dir = '';
    originalAddrList = new Array();
    mId = '';
    prefixNum = 0;
    downloadAddrList = new Array();
    saveAddrList = new Array();
    replaceAddrList = new Array();
}

function config(config, saveTo, file, box, arrUrls) {
    cfg = config;
    dest = saveTo;

    box.forEach((item) => {
        if (item.css === file) {
            dir = item.dir;
        }
    });
    
    originalAddrList = arrUrls;
}

function mockId(val) {
    mId = val;
}

function mockCssBox(file, box) {
    box.forEach((item) => {
        if (item.css === file) {
            dir = item.dir;
        }
    });
}

function parse() {
    const digFileName = (url) => {
        let arr = url.split('/');
        let fileName = arr.length > 1 ? arr[arr.length - 1] : url;

        let exclamationPos = fileName.indexOf('!');
        let questionPos = fileName.indexOf('?');
        if (exclamationPos > -1 || questionPos > -1) {
            if (exclamationPos > -1) fileName = fileName.substr(0, exclamationPos);
            if (questionPos > -1) fileName = fileName.substr(0, questionPos);
        }

        if (mId) {
            return path.join(dest, 'css_' + mId + '_' + fileName);
        } else {
            prefixNum += 1;
            
            return path.join(dest, 'css_' + prefixNum.toString(16) + '_' + fileName);
        }
    }

    const parseUrl = (item) => {
        const parsed = digFileName(item);
        const firstOne = item.substr(0, 1);
        const firstTwo = item.substr(0, 2);
        const protocol = dir.substr(0, 7) === 'http://' ? 'http://' : 'https://';

        if (item.substr(0, 7) === 'http://' || item.substr(0, 8) === 'https://') {
            return {
                downloadAddr: item,
                saveAddr: parsed,
                replaceAddr: parsed.substr(parsed.indexOf('\\') + 1)
            };
        }

        if (firstTwo === '//') {
            return {
                downloadAddr: protocol + item.substr(2),
                saveAddr: parsed,
                replaceAddr: parsed.substr(parsed.indexOf('\\') + 1)
            };
        }

        if (firstOne === '/') {
            return {
                downloadAddr: dir + item.substr(1),
                saveAddr: parsed,
                replaceAddr: parsed.substr(parsed.indexOf('\\') + 1)
            };
        } else {
            return {
                downloadAddr: dir + item,
                saveAddr: parsed,
                replaceAddr: parsed.substr(parsed.indexOf('\\') + 1)
            };
        }
    }

    originalAddrList.forEach((addr) => {
        let surround = '';
        let matched = false;

        cfg.surround.forEach((sur) => {
            if (!matched && addr.substr(0, sur.length) === sur) {
                matched = true;
                surround = sur;
                addr = addr.substr(surround.length, addr.length - 2 * surround.length);
            }
        });

        const ret = parseUrl(addr);
        downloadAddrList.push(ret.downloadAddr);
        saveAddrList.push(ret.saveAddr);
        surround != '' ? replaceAddrList.push(surround + ret.replaceAddr + surround) : replaceAddrList.push(ret.replaceAddr);
    });
}

module.exports = {
    reset: reset,
    config: config,
    mockId: mockId,
    mockCssBox: mockCssBox,
    parse: parse,
    downloadAddrList: () => { return downloadAddrList; },
    saveAddrList: () => { return saveAddrList; },
    replaceAddrList: () => { return replaceAddrList; }
};