
let cfg = {};
let content = '';
let tags = new Array();
let originalAddrList = new Array();
let curPos = 0;
let curTag = '';

function reset() {
    cfg = {};
    content = '';
    tags = new Array();
    originalAddrList = new Array();
    curPos = 0;
    curTag = '';
}

function config(digCfg, fileContent) {
    cfg = digCfg;
    content = fileContent;
}

function findPartForAll() {
    const result = findPart(content, curPos, content.length, cfg.begin, cfg.end);

    if (result) {
        tags.push(result.value);
        curPos = result.pos;
        curTag = result.value;
        return true;
    }

    return false;
}

function findPart(findInContent, pos, limit, begin, end) {
    const tryGetPos = (str, pos)=> {
        while (pos < limit) {
            if (findInContent.substr(pos, str.length) === str) {
                return pos;
            } else {
                pos += 1;
            }
        }

        return null;
    }

    const bPos = tryGetPos(begin, pos);
    const ePos = tryGetPos(end, bPos + begin.length);
    
    if (bPos != null && ePos != null) {
        const newPos =  ePos + end.length;
        const val = findInContent.substr(bPos, (ePos - bPos + 1));
    
        return {
            value: val,
            pos: newPos
        };
    }
    
    return null;
}

function keepClear() {
    curTag = curTag.replace(new RegExp(cfg.clear, 'g'), '');
}

function isValid() {
    let check = true;

    if (cfg.ignoreTag) {
        cfg.ignoreTag.forEach((item) => {
            if (curTag.substr(0, item.length) === item) {
                check = false;
            }
        });
    }

    if (check && cfg.ignoreTagUnless) {
        let isBegin = true;
        let matched = false;
        let matchTag = null;
        let matchVal = null;

        cfg.ignoreTagUnless.forEach((item) => {
            if (isBegin) {
                isBegin = false;
                matched = false;

                if (curTag.substr(0, item.length) === item) {
                    matched = true;
                    matchTag = true;
                }
            } else {
                isBegin = true;

                if (matched && curTag.match(new RegExp(item))) {
                    matchVal = true;
                }
            }
        });

        if (matchTag && !matchVal) {
            check = false;
        }
    }
    
    if (check && cfg.ignoreProp) {
        cfg.ignoreProp.forEach((item) => {
            if (curTag.match(new RegExp(item))) {
                check = false;
            }
        });
    }

    return check;
}

function analyze() {
    let result = '';
    let lastItem = null;

    cfg.findProp.forEach((item) => {
        if (!lastItem) {
            lastItem = item;
        } else {
            result = findPart(curTag, 0, curTag.length, lastItem, item);

            if (result) {
                result.value = result.value.substr(lastItem.length);
                result.value = result.value.substr(0, result.value.length - item.length);

                if (result.value.trim().length > 0 && originalAddrList.indexOf(result.value) === -1) {
                    originalAddrList.push(result.value);
                }
            }
            lastItem = null;
        }
    });
}

function dig() {
    while (findPartForAll()) {
        keepClear();
        
        if (isValid()) {
            analyze();
        }
    }
}

module.exports = {
    reset: reset,
    config: config,
    dig: dig,
    tags: () => { return tags; },
    originalAddrList: () => { return originalAddrList; }
}
