
const log = require('console').log;

const fs = require('fs');
const http = require('http');
const https = require('https');

function downloadAllOfThese(isVerbose, prefix, downloadAddrList, saveAddrList) {
    return new Promise((resolve) => {
        let cur = 0;
        const len = downloadAddrList.length;
        const streams = new Array();

        for (let i = 0; i < len; i++) {
            const protocol = downloadAddrList[i].substr(0, 7) === 'http://' ? 'http://' : 'https://';
            const lib = getLib(protocol);
            streams[i] = fs.createWriteStream(saveAddrList[i]);
            
            lib.get(downloadAddrList[i], (res) => {
                res.pipe(streams[i]);
    
                streams[i].on('finish', () => {
                    isVerbose && log(prefix + 'finished - ' + downloadAddrList[i]);
                    streams[i].close();

                    cur++;
                    if (cur === len) resolve(); 
                });
            }).on('error', (err) => {
                fs.unlink(saveAddrList[i]);
                isVerbose && log(prefix + 'error when downloading - ' + downloadAddrList[i] + ' error message: ' + err);

                cur++;
                if (cur === len) resolve(); 
            });
        }
    })
}

function getLib(protocol) {
    return {'http://' : http, 'https://' : https}[protocol];
}

module.exports = {
    downloadAllOfThese: downloadAllOfThese
}