
const path = require('path');

let cfg = {};
let dest = '';
let reqURL = '';
let originalAddrList = new Array();
let protocol = '';
let host = '';
let mId = '';
let prefixNum = 0;
let downloadAddrList = new Array();
let saveAddrList = new Array();
let replaceAddrList = new Array();
let cssBox = new Array();

function reset() {
    cfg = {};
    dest = '';
    reqURL = '';
    originalAddrList = new Array();
    protocol = '';
    host = '';
    prefixNum = 0;
    downloadAddrList = new Array();
    saveAddrList = new Array();
    replaceAddrList = new Array();
    cssBox = new Array();
}

function config(config, saveTo, req, arrUrls) {
    cfg = config;
    dest = saveTo;
    reqURL = req.substr(req.length - 1) === '/' ? req : req + '/';
    originalAddrList = arrUrls;

    if (reqURL.substr(0, 7) != 'http://' && reqURL.substr(0, 8) != 'https://') {
        throw new Error();
    }

    protocol = reqURL.substr(0, 7) === 'http://' ? 'http://' : 'https://';
    const reg = new RegExp('https?://(.+)/');
    host = reqURL.match(reg)[1];
}

function mockId(val) {
    mId = val;
}

function parse() {
    const digFileName = (url) => {
        let arr = url.split('/');
        let fileName = arr.length > 1 ? arr[arr.length - 1] : url;

        let exclamationPos = fileName.indexOf('!');
        let questionPos = fileName.indexOf('?');
        if (exclamationPos > -1 || questionPos > -1) {
            if (exclamationPos > -1) fileName = fileName.substr(0, exclamationPos);
            if (questionPos > -1) fileName = fileName.substr(0, questionPos);
        }

        if (mId) {
            return path.join(dest, mId + '_' + fileName);
        } else {
            prefixNum += 1;

            return path.join(dest, prefixNum.toString(16) + '_' + fileName);
        }
    }

    const parseUrl = (item) => {
        const parsed = digFileName(item);
        const firstOne = item.substr(0, 1);
        const firstTwo = item.substr(0, 2);

        if (firstTwo === '//') {
            return {
                downloadAddr: protocol + item.substr(2),
                saveAddr: parsed,
                replaceAddr: parsed
            };
        }

        if (firstTwo === './' || firstOne === '/') {
            const index = firstOne === '/' ? 1 : 2;

            return {
                downloadAddr: protocol + host + '/' + item.substr(index, item.length - index),
                saveAddr: parsed,
                replaceAddr: parsed
            };
        }

        if (item.substr(0, 7) === 'http://' || item.substr(0, 8) === 'https://') {
            return {
                downloadAddr: item,
                saveAddr: parsed,
                replaceAddr: parsed
            };
        }

        return {
            downloadAddr: protocol + host + '/' + item,
            saveAddr: parsed,
            replaceAddr: parsed
        };
    }

    originalAddrList.forEach((addr) => {
        let surround = '';
        let matched = false;

        cfg.surround.forEach((sur) => {
            if (!matched && addr.substr(0, sur.length) === sur) {
                matched = true;
                surround = sur;
                addr = addr.substr(surround.length, addr.length - 2 * surround.length);
            }
        });

        const ret = parseUrl(addr);
        downloadAddrList.push(ret.downloadAddr);
        saveAddrList.push(ret.saveAddr);
        surround != '' ? replaceAddrList.push(surround + ret.replaceAddr + surround) : replaceAddrList.push(ret.replaceAddr);
        
        if (ret.saveAddr.substr(ret.saveAddr.length - 4) === '.css') {
            let pos = ret.downloadAddr.lastIndexOf('/');
            
            cssBox.push({
                css: ret.saveAddr,
                dir: ret.downloadAddr.substr(0, pos + 1)
            });
        }
    });
}

module.exports = {
    reset: reset,
    config: config,
    mockId: mockId,
    parse: parse,
    currentURL: () => { return reqURL; },
    downloadAddrList: () => { return downloadAddrList; },
    saveAddrList: () => { return saveAddrList; },
    replaceAddrList: () => { return replaceAddrList; },
    cssBox: () => { return cssBox; }
};